struct Socket {
family: SocketFamily,
state: RefCell<SocketState>,
is_non_block: Cell<bool>,
io_readiness: RefCell<BlockingIoSourceReadiness>,
error: RefCell<Option<Error>>,
read_timeout: Cell<Option<Duration>>,
write_timeout: Cell<Option<Duration>>,
}Fields
family: SocketFamilyFamily of the socket, used to ensure socket only binds/connects to address of same family.
state: RefCell<SocketState>Current state of the inner socket.
is_non_block: Cell<bool>Whether this fd is non-blocking or not.
io_readiness: RefCell<BlockingIoSourceReadiness>The current blocking I/O readiness of the file description.
error: RefCell<Option<Error>>Some when the socket had an async error which has not yet been fetched via SO_ERROR.
read_timeout: Cell<Option<Duration>>Read timeout of the socket. None means that reads can block indefinitely.
The timeout is applied to the monotonic clock (the Unix specification doesn’t
specify which clock to use, but the monotonic clock is more common for
relative timeouts).
This is ignored when the socket is non-blocking.
write_timeout: Cell<Option<Duration>>Write timeout of the socket. None means that writes can block indefinitely.
The timeout is applied to the monotonic clock (the Unix specification doesn’t
specify which clock to use, but the monotonic clock is more common
for relative timeouts).
This is ignored when the socket is non-blocking.